#!/bin/csh 

#####################################
#
# Name: linux_vmwes92_install.csh
#
# Author: Darrel Kingfield CIMMS/WDTB
#
# Desc: Inflates the contents of the
# vm_wes archive directory to a 
# directory of your choice.
#
#####################################

#check for correct user arguments
if ($#argv < 1) then
	echo ""
	echo "USAGE: $0 <installation_path>"
	echo "EXAMPLE: $0 /usr/local"
	echo ""
	exit
endif

set installDir = $1
set you = `whoami`

#check for root user
if ("$you" != "root") then
	echo ""
	echo "You must be the root user to install this case"
	echo "and you currently are the $you user."
	echo ""
	exit
endif

echo ""
echo "~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~="
echo "This script will inflate the contents of the Virtual"
echo "GOES-R WES Case into the $installDir/vm_wes92 path."
echo ""
echo "The unpackaged contents of this case will require ~40GB"
echo "of space to run. Please ensure there is enough space"
echo "in the $installDir path"
echo ""
echo "e.g. %> df -h $installDir"
echo ""
echo "Are you ready to proceed (y/n)?" ; set yORn = $<
if ("$yORn" != "y" && "$yORn" != "Y") then
        echo ""
        echo "Please run the $0 script when you are ready to proceed"
        echo ""
        exit
endif
echo "~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~="
echo "CHECKING SYSTEM FOR NECESSARY COMPONENTS"
echo "~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~="
#sanity check for installation directory
echo "Checking if $installDir/vm_wes92 exists..."
if (! -e $installDir/vm_wes92) then
	echo "---Creating $installDir/vm_wes92 path..."
	mkdir -p $installDir/vm_wes92
else
	echo "---$installDir/vm_wes92 exists...skipping"
endif
echo "~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~="
echo "INFLATING THE VM ARCHIVE INTO $installDir/vm_wes92"
echo "~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~="
#opening up contents of vm_wes
foreach vmPart (`ls *.zip`)
	echo "Unzipping $vmPart..."
	unzip $vmPart -d $installDir/vm_wes92
end
echo "Changing permissions on $installDir/vm_wes92..."
chmod -R 777 $installDir/vm_wes92
echo "~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~=-~="
echo ""
echo "$0 COMPLETED!"
echo ""
exit
